import { BasicColumn, FormSchema } from '@/components/Table';
import { DescItem } from '@/components/Description';

export const columns: BasicColumn[] = [
  {
    title: '调度时间',
    dataIndex: 'dispatchTime',
    width: 160,
  },
  {
    title: '执行时间',
    dataIndex: 'executeTime',
    width: 160,
  },
  {
    title: '影响行数',
    dataIndex: 'rows',
    width: 90,
  },
  {
    title: '执行时长',
    dataIndex: 'executeDuration',
    width: 90,
  },
  {
    title: '运行状态',
    dataIndex: 'operationalStatus',
    width: 90,
    slots: { customRender: 'operationalStatus' },
  },
  {
    title: '执行版本',
    dataIndex: 'version',
    width: 90,
  },
  {
    title: '执行模式',
    dataIndex: 'executeMode',
    width: 90,
  },
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    colProps: { span: 8 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
  {
    field: 'flag',
    label: ' ',
    component: 'Select',
    componentProps: {
      placeholder: '按来源过滤',
      options: [{ label: '指标汇总表', value: '1' }],
    },
    colProps: { span: 8 },
  },
];

/**左上角表单*/
export const resetNameFormSchema: FormSchema[] = [
  {
    field: 'schedulingTime',
    component: 'RadioButtonGroup',
    colProps: {
      lg: 4,
      md: 4,
    },
    defaultValue: '1',
    componentProps: {
      options: [
        {
          label: '调度时间',
          value: '1',
        },
        {
          label: '执行时间',
          value: '2',
        },
      ],
      onChange: (e) => {
        console.log(e);
      },
    },
  },
  {
    field: 'days',
    component: 'DatePicker',
    colProps: {
      lg: 3,
      md: 3,
    },
    defaultValue: new Date(),
    componentProps: {
      format: 'YYYY-MM-DD',
      placeholder: '选择日期范围',
    },
  },

  {
    field: 'schedulingType',
    component: 'Select',
    label: '调度类型',
    colProps: {
      lg: 4,
      md: 4,
    },
    defaultValue: '1',
    componentProps: {
      options: [
        {
          label: '不限',
          value: '1',
          key: '1',
        },
        {
          label: '不限2',
          value: '2',
          key: '2',
        },
        {
          label: '不限3',
          value: '3',
          key: '3',
        },
      ],
    },
  },
  {
    field: 'publishingStatus',
    component: 'Select',
    label: '发布状态',
    colProps: {
      lg: 4,
      md: 4,
    },
    defaultValue: '1',
    componentProps: {
      options: [
        {
          label: '不限',
          value: '1',
          key: '1',
        },
        {
          label: '不限2',
          value: '2',
          key: '2',
        },
        {
          label: '不限3',
          value: '3',
          key: '3',
        },
      ],
    },
  },
  {
    field: 'refresh',
    label: ' ',
    colProps: {
      lg: 9,
      md: 9,
    },
    component: 'Slot',
    slot: 'refresh',
  },
];

export const schema: DescItem[] = [
  {
    field: 'schedulingCycle',
    label: '调度周期',
  },
  {
    field: 'publishingStatus',
    label: '发布状态',
  },
  {
    field: 'createdBy',
    label: '创建者',
  },
];
export const detailsColumns: BasicColumn[] = [
  {
    title: '源表',
    dataIndex: 'sourceTable',
    width: 100,
  },
  {
    title: '目标表',
    dataIndex: 'targetTable',
    width: 100,
  },
  {
    title: '描述',
    dataIndex: 'describe',
    width: 170,
  },
  {
    title: '运行状态',
    dataIndex: 'callStatus',
    width: 100,
    slots: { customRender: 'callStatus' },
  },
  {
    title: '影响行数',
    dataIndex: 'rows',
    width: 100,
  },
];

export const detailSchemas: FormSchema[] = [
  {
    field: 'name',
    label: '',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入关键字搜索',
    },
  },
];

export const importFormSchema: any[] = [
  {
    field: 'fileMethods',
    label: '导入文件选择',
    slot: 'fileMethods',
    colProps: { lg: 24, md: 24, offset: 3 },
  },
  {
    field: 'fileRename',
    label: '文件重名',
    component: 'RadioGroup',
    required: true,
    colProps: { lg: 24, md: 24, offset: 3 },
    componentProps: {
      options: [
        { label: '全部放弃', value: '1' },
        { label: '全部替换', value: '2' },
        { label: '自动重命名', value: '3' },
      ],
    },
  },
];
